@@ -175,7 +175,6 @@ def exists(file_path, **kwargs):
     '''
 
     ftp = obj.get_kwarg(["ftp"], None, None, **kwargs)
-
     if ftp is not None:
         if ftp.path.isfile(file_path):
             if ftp.path.exists(file_path):
@@ -1073,6 +1072,7 @@ def get_files(search_path=False, **kwargs):
             A list of dictionaries containing all matching files.
     '''
     file_array = []
+
     if search_path is False:
         search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
     if isinstance(search_path, list) is False:
@@ -1094,8 +1094,7 @@ def get_files(search_path=False, **kwargs):
     if isinstance(include, (str)):
         include = [include]
 
-    extension_array = strUtils.format.extension(
-        obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
+    extension_array = strUtils.format.extension(obj.get_kwarg(['extensions', 'ext', 'extension'], [], (str, list), **kwargs))
     if isinstance(extension_array, (str)):
         extension_array = [extension_array]
 
@@ -1109,6 +1108,7 @@ def get_files(search_path=False, **kwargs):
             return gft.master()
     # print(json.dumps(extension_array, indent=4))
     for path in search_path:
+        path = strUtils.format.file_path(path)
         # pylint: disable=unused-variable
         for root, folders, files in os.walk(path):
             for file in files:
@@ -1117,14 +1117,17 @@ def get_files(search_path=False, **kwargs):
                     # ignore = False
                     # print(f"file_data['extension']: {file_data['extension']}")
                     if len(exclude) > 0:
+                        # print(f"filtering excludes")
                         if strUtils.parse.array_in_string(exclude, file_data['file_path']) is True:
                             continue
 
                     if len(include) > 0:
+                        # print(f"filtering includes")
                         if strUtils.parse.array_in_string(include, file_data['file_path']) is False:
                             continue
 
                     if len(extension_array) > 0:
+                        # print(f"filtering extension_array")
                         file_ext = strUtils.format.extension(file_data['extension'])
                         if file_ext not in extension_array:
                             continue
@@ -1136,11 +1139,14 @@ def get_files(search_path=False, **kwargs):
 
                     # if ignore is False:
                         # fd['file_hash'] = generateFileHash(fd['file_path'])
+                    # print(f"file found.")
                     file_array.append(file_data)
-
+                # else:
+                    # print(f"file_data is none")
             if recursive is False:
+                # print(f"breaking")
                 break
-        return file_array
+
         # path_files = index_files(path, extension_array, ignore_array, recursive)
         # file_array = path_files + file_array
     return file_array
@@ -1269,13 +1275,13 @@ class GetFilesThreaded:
 
     def __init__(self, search_path, **kwargs):
         self.threads = []
+        self.thread_array = []
         self.file_array = []
         self.max_threads = 20
         self.search_path = search_path
 
         if search_path is False:
-            self.search_path = obj.get_kwarg(
-                ['search path', 'search'], os.getcwd(), (str, list), **kwargs)
+            self.search_path = obj.get_kwarg(['search path', 'search'], os.getcwd(), (str, list), **kwargs)
         if isinstance(self.search_path, list) is False:
             self.search_path = [self.search_path]
 
@@ -1287,8 +1293,7 @@ class GetFilesThreaded:
 
         # ignore_array = obj.get_kwarg(
             # ['ignore', 'ignore_array', 'exclude'], [], (str, list), **kwargs)
-        self.exclude = obj.get_kwarg(
-            ['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
+        self.exclude = obj.get_kwarg(['exclude', 'ignore', 'ignore array'], [], (list, str), **kwargs)
         if isinstance(self.exclude, (str)):
             self.exclude = [self.exclude]
 
@@ -1394,7 +1399,7 @@ class GetFilesThreaded:
             # pylint: disable=unused-variable
             for root, folders, files in os.walk(path):
 
-                # print(f"Active Threads: {csu.format.left_pad(len(self.threads),3,'0')} Total Files: {len(self.file_array)}", end="\r", flush=True)
+                # print(f"Active Threads: {strUtils.format.left_pad(len(self.threads),3,'0')} Total Files: {len(self.file_array)}", end="\r", flush=True)
                 while len(self.threads) >= self.max_threads:
                     time.sleep(.1)
 
@@ -1405,6 +1410,7 @@ class GetFilesThreaded:
                 }
                 thread = Thread(target=self.single_file_thread, args=(data,))
                 self.threads.append(data['thread_id'])
+                self.thread_array.append(thread)
                 thread.start()
 
                 if self.recursive is False:
@@ -1413,6 +1419,8 @@ class GetFilesThreaded:
             # path_files = index_files(path, extension_array, ignore_array, recursive)
             # file_array = path_files + file_array
         # print(f"                                                                                                                      ", end="\r", flush=True)
+        for thread in self.thread_array:
+            thread.join()
         return self.file_array
 
         # def _get_files_single_thread(search_path=False, recursive=False, exclude=None, include=None, extensions=None, data_include=None):
